# python-template-repository
Template repository for python

## How to use
- Use the repo as a github template to create a new repository
- Initiate poetry and follow the instructions
```bash
poetry init
```
- Update the `OWNERS` file relevant sections
- If needed, add more checks in `tox.ini`
